@@ -4,7 +4,7 @@ use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 use namespace::clean;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -32,6 +32,37 @@ statically as C<0.001>. See L<Dist::Zilla::PluginBundle::Starter/"Versions">
 for ways to automatically manage distribution versions between releases with
 L<Dist::Zilla>.
 
+=head1 CUSTOMIZING
+
+It's easy to create your own local version of this (or any other) minting
+profile which you can customize as you choose. First create a new directory in
+C<profiles> in your dzil configuration folder:
+
+  $ mkdir -p ~/.dzil/profiles/myminter
+
+Then, copy the contents from the profile you want (such as the
+C<profiles/default> directory of this distribution). Modify the copied files to
+your liking, and then you can use it to mint a distribution.
+
+  $ dzil new -p myminter My::New::Dist
+
+You can also specify a default provider (C<-P> option) or profile (C<-p>
+option) in your dzil config (C<~/.dzil/config.ini>).
+
+  ; config.ini
+  [%Mint]
+  profile = myminter
+
+  ; or
+  [%Mint]
+  provider = Starter
+
+  $ dzil new My::New::Dist # now uses the specified provider and/or profile
+
+If no provider or profile is configured or specified, C<dzil new> will use the
+C<default> local profile, or the default C<[@Basic]> profile shipped with
+L<Dist::Zilla>.
+
 =head1 BUGS
 
 Report any issues on the public bugtracker.
